@@ -65,7 +65,9 @@ test_that(
         formula = interval ~ age
       )
 
-    expect_equal(dim(lmer_df), c(2L, 7L))
+    expect_equal(nrow(lmer_df), 2)
+    ## allow for nobs to be included in later versions of broom.mixed
+    expect_true(ncol(lmer_df) %in% c(7, 8))
     expect_equal(dim(lm_df)[1], 2L)
 
     expect_snapshot(list(lmer_df, lm_df))
